#include "p5.h"
#include <qvbox.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qsplitter.h>
#include <dcopclient.h>
#include <kapp.h>
#include <kmenubar.h>
#include <klocale.h>
#include <kpopupmenu.h>
#include <khtml_part.h>
#include <kdebug.h>

MainWindow::MainWindow ( const char * name ) : KMainWindow ( 0L, name )
{
  setCaption("p5");

  QPopupMenu * filemenu = new QPopupMenu;
  filemenu->insertItem( i18n( "&Quit" ), kapp, SLOT( quit() ) );
  QString about =
    i18n("p5 1.0\n\n"
	"(C) 1999-2002 Antonio Larrosa Jimenez\n"
	"larrosa@kde.org\t\tantlarr@supercable.es\n"
	"Malaga (Spain)\n\n"
	"Simple KDE Tutorial\n"
	"This tutorial comes with ABSOLUTELY NO WARRANTY \n"
	"This is free software, and you are welcome to redistribute it\n"
	"under certain conditions\n");

  QPopupMenu *helpmenu = helpMenu(about);  
  KMenuBar * menu = menuBar();
  menu->insertItem( i18n( "&File" ), filemenu);
  menu->insertSeparator();
  menu->insertItem(i18n("&Help"), helpmenu);

  QVBox * vbox = new QVBox ( this );

  location = new QLineEdit ( vbox );
  location->setText( "http://localhost" );

  connect( location , SIGNAL( returnPressed() ),
      this, SLOT( changeLocation() ) );

  split = new QSplitter ( vbox );
  split->setOpaqueResize();

  bookmark = new QPushButton ( i18n("Add to Bookmarks"), split );

  connect( bookmark, SIGNAL( clicked() ), this, SLOT( bookLocation() ) );

  browser=new KHTMLPart( split );
  browser->openURL( location->text() );

  connect( browser->browserExtension(),
      SIGNAL( openURLRequest( const KURL &, const KParts::URLArgs & ) ),
      this, SLOT( openURLRequest(const KURL &, const KParts::URLArgs & ) ) );         

  setCentralWidget( vbox );

  DCOPClient *client = kapp->dcopClient();
  client->attach();
}


void MainWindow::changeLocation()
{
  browser->openURL( location->text() );
}

void MainWindow::openURLRequest(const KURL &url, const KParts::URLArgs & )
{
  location->setText( url.url() );
  changeLocation();
} 

void MainWindow::bookLocation()
{
  DCOPClient *client=kapp->dcopClient();
  QByteArray params;
  QDataStream stream(params, IO_WriteOnly);
  stream << location->text();
  if (!client->send("p6-*", "bookmarkList", "add(QString)", params))
    kdDebug() << "Error with DCOP\n" ;
}
